varying vec2 texCoord;

uniform int pass;

uniform sampler2D texOriginal;
uniform sampler2D texPost;

float Luminance( vec3 _color );

vec4 BlurHorizontal( in sampler2D _tex, in vec2 _texCoord, in int _pass );
vec4 BlurVertical( in sampler2D _tex, in vec2 _texCoord, in int _pass );

void main()
{
	vec4 texelModified = vec4( 1.0 );
	vec4 texelOriginal = vec4( 1.0 );
	
	if( pass == 1 )
	{
		texelOriginal = texture2D( texOriginal, texCoord );
		
		texelModified = vec4( ( texelOriginal.rgb * 
								clamp( Luminance( texelOriginal.rgb ) * 8.0 - 3.5, 0.0, 1.0 ) ) * 
								texelOriginal.a, texelOriginal.a );
	}
	else if( pass == 2 || pass == 4 )
	{
		if( pass == 2 )
		{
			texelModified = BlurVertical( texPost, texCoord, 1 );
		}
		else if( pass == 4 )
		{
			texelModified = BlurVertical( texPost, texCoord , 2 );
		}
	}
	else if( pass == 3 || pass == 5 )
	{
		if( pass == 3 )
		{
			texelModified = BlurHorizontal( texPost, texCoord, 1 );
		}
		else if( pass == 5 )
		{
			texelModified = BlurHorizontal( texPost, texCoord , 2 );
		}
	}
	else if( pass == 6 )
	{
		texelOriginal = texture2D( texOriginal, texCoord );
		texelModified = texture2D( texPost, texCoord );
  
     	texelModified += texelOriginal;   	
	}
	
	gl_FragColor = texelModified;
}

float Luminance( vec3 _color )
{
	float fmin = min( min( _color.r, _color.g ), _color.b );    //Min. value of RGB
	float fmax = max( max( _color.r, _color.g ), _color.b );    //Max. value of RGB

	return ( fmax + fmin ) / 2.0; // Luminance
}

vec4 BlurHorizontal( in sampler2D _tex, in vec2 _texCoord, in int _pass )
{
	float texScaler;
	
	if( _pass == 1 )
	{
		texScaler = 2.0 / 256.0;
	}
	else if( _pass == 2 )
	{
		texScaler = 0.5 / 256.0;
	}	
	
    vec4 color = vec4(0.0,0.0,0.0,0.0);
  
    vec4 gaussFilter[7];
   
	gaussFilter[0] = vec4(-3.0, 0.0, 0.0,  1.0/64.0);
	gaussFilter[1] = vec4(-2.0, 0.0, 0.0,  6.0/64.0);
	gaussFilter[2] = vec4(-1.0, 0.0, 0.0, 15.0/64.0);
	gaussFilter[3] = vec4( 0.0, 0.0, 0.0, 20.0/64.0);
	gaussFilter[4] = vec4( 1.0, 0.0, 0.0, 15.0/64.0);
	gaussFilter[5] = vec4( 2.0, 0.0, 0.0,  6.0/64.0);
	gaussFilter[6] = vec4( 3.0, 0.0, 0.0,  1.0/64.0);
	   
	for( int i = 0; i < 7; i++ )
	{
		color += texture2D( _tex, vec2( _texCoord.x + gaussFilter[i].x * texScaler,
		                                _texCoord.y + gaussFilter[i].y * texScaler ) ) * 
		                    			gaussFilter[i].w;
	} // End for
	   
	color.a = 1.0;
	
	return color;
}

vec4 BlurVertical( in sampler2D _tex, in vec2 _texCoord, in int _pass )
{
	float texScaler;
	
	if( _pass == 1 )
	{
		texScaler = 2.0 / 256.0;
	}
	else if( _pass == 2 )
	{
		texScaler = 0.5 / 256.0;
	}	

    vec4 color = vec4(0.0,0.0,0.0,0.0);
  
    vec4 gaussFilter[7];
   
	gaussFilter[0] = vec4(0.0, -3.0, 0.0,  1.0/64.0);
	gaussFilter[1] = vec4(0.0, -2.0, 0.0,  6.0/64.0);
	gaussFilter[2] = vec4(0.0, -1.0, 0.0, 15.0/64.0);
	gaussFilter[3] = vec4(0.0,  0.0, 0.0, 20.0/64.0);
	gaussFilter[4] = vec4(0.0,  1.0, 0.0, 15.0/64.0);
	gaussFilter[5] = vec4(0.0,  2.0, 0.0,  6.0/64.0);
	gaussFilter[6] = vec4(0.0,  3.0, 0.0,  1.0/64.0);
	   
	for( int i = 0; i < 7; i++ )
	{
	    color += texture2D( _tex, vec2( _texCoord.x + gaussFilter[i].x * texScaler,
	                                    _texCoord.y + gaussFilter[i].y * texScaler)) * 
	                    				gaussFilter[i].w;
	} // End for
	   
	color.a = 1.0;
	
	return color;
}
