varying vec3 L,		// light position
			 N,		// normal vector
			 C;		// camera position

uniform sampler2D texDiffuse0,
				  texDiffuse1,
				  texDiffuse2,
				  texSpec,
				  texNoise;

uniform float offset;

void main()
{
	vec3  R,			// reflected value
		  cD,			// total color day
		  cDA,			// atmos scatter adjust
		  cN,			// total color night
		  IT,			// intensity total
		  atmos;			
	
	vec4 texelDay,		// texel from earth day texture
		 texelNight,
		 texelClouds,
		 texelSpec,
		 texelNoise;	// texel from noise texture
		 
	float I,			// light intensity
		  IC,			// light intensity color multiplyer
	      RL,			// rim lighting
	      S,			// specualar lighting
	      noise;		// noise for specular modulation
	 
	float localOffset = mod( offset, 1.0 );
		      
	// get all texture texels
	texelDay = texture2D( texDiffuse0, gl_TexCoord[0].st );
	texelNight = texture2D( texDiffuse1, gl_TexCoord[0].st ) * 1.5;
	texelClouds = texture2D( texDiffuse2, gl_TexCoord[0].st + vec2( localOffset, 0.0 ) );		
	texelSpec = texture2D( texSpec, gl_TexCoord[0].st );
	texelNoise = texture2D( texNoise, gl_TexCoord[0].st * vec2( 10.0, 5.0 ) );	
	
	// calculate intensity value
	I = max( dot( L,  N ), 0.0 );
	IC = clamp( I * 1.5, 0.0, 1.0 );
	
	// calculate rim light value
	RL = pow( 1.35 - max( dot( C, N ) ,0.0 ), 5.0 );
	
	// calculate noise value
	noise = clamp( ( texelNoise.r * texelSpec.r ), 0.0, 1.0 );
	
	// calculate reflection value
	R = reflect( -L, N ) * ( 1.0 - clamp( RL, 0.0, 1.0 ) );
	
	// calcualte specular value
	S = pow( max( dot( R, C ), 0.0 ), clamp( gl_FrontMaterial.shininess, 0.1, 100.0 ) ) * 0.75;
			
	// calculate total intensity
	IT = ( (  I + ( I * RL ) ) * gl_FrontMaterial.diffuse.rgb) + gl_FrontMaterial.ambient.rgb;
	
	// calculate light intensity color multiplyer
	cDA = vec3( clamp( IC * 4.0, 0.0, 1.0 ), clamp( IC * 2.0, 0.0, 1.0 ), clamp( IC, 0.0, 1.0 ) );
	
	// calculate day and night final colors
	cD = ( ( clamp( ( texelDay.rgb * cDA + texelClouds.rgb ), 0.0, 1.0 ) * IT ) + ( S * noise ) );
	cN = ( texelNight.rgb * clamp( ( 1.0 - texelClouds.rgb ), 0.0, 1.0 ) ) * clamp( ( pow( 1.0 - I, 2.0 ) ), 0.0, 1.0 );
	
	// output final color and alpha
	gl_FragColor = vec4( cD + cN, clamp( I * pow( RL, 1.5 ), 0.0, 1.0 ) );	
}
