varying vec3 L,		// light position
			 N,		// normal vector
			 C;		// camera position

uniform sampler2D texDiffuse0,
				  texDiffuse1,
				  texSpec,
				  texNoise;

uniform float offset;

void main()
{
	vec3  R,			// reflected value
		  ct,			// total color
		  IT;			// intensity total			
	
	vec4 texelColor1,
		 texelColor2,	// texel from earth day texture
		 texelSpec1,
		 texelSpec2,
		 texelBlurMask,
		 texelNoise;	// texel from noise texture
		 
	float I,			// light intensity
	      RL,			// rim lighting
	      S,			// specualar lighting
	      noiseA,
	      noiseB,
	      noise;		// noise for specular modulation
	      
	float localOffset = mod( offset, 2.0 );
	      
	// get all texture texels
	texelColor1 = texture2D( texDiffuse0, gl_TexCoord[0].st + vec2( mod( localOffset, 1.0 ), 0.0 ) * 4.0 );	
	texelColor2 = texture2D( texDiffuse0, gl_TexCoord[0].st - vec2( localOffset, 0.0 ) * 0.5 );	
	texelSpec1 = texture2D( texSpec, gl_TexCoord[0].st + vec2( mod( localOffset, 1.0 ), 0.0 ) * 4.0 );
	texelSpec2 = texture2D( texSpec, gl_TexCoord[0].st - vec2( localOffset, 0.0 ) * 0.5 );
	texelNoise = texture2D( texNoise, gl_TexCoord[0].st + vec2( localOffset, 0.0 ) );		
	texelBlurMask = texture2D( texDiffuse1, gl_TexCoord[0].st);	
	
	texelBlurMask = 1.0 - ( ( 1.0 - texelBlurMask ) * clamp( ( texelNoise + 0.75 ), 0.0, 1.0 ) );
	
	// calculate intensity value
	I = max( dot( L, N ), 0.0 );
	
	// calculate rim light value
	RL = pow( 1.35 - max( dot( C, N ) , 0.0 ), 10.0 ) * 0.5;
	
	// calculate noise value
	noiseA = clamp( ( texelNoise.r + 0.25 ) * texelSpec1.r, 0.0, 1.0 );
	noiseB = clamp( ( texelNoise.r + 0.25 ) * texelSpec2.r, 0.0, 1.0 );	
	
	noise = noiseA * texelBlurMask.r + ( noiseB * ( 1.0 - texelBlurMask.r ) );
	
	// calculate reflection value
	R = reflect( -L, N ) * ( 1.0 - clamp( RL, 0.0, 1.0 ) );
	
	// calculate specular value
	S = pow( max( dot( R, C ), 0.0 ), clamp( gl_FrontMaterial.shininess, 1.0, 100.0 ) ) * 0.75;
	
	// calculate total intensity
	IT = ( ( I + ( I * RL ) ) * gl_FrontMaterial.diffuse.rgb ) + gl_FrontMaterial.ambient.rgb;
	
	// calculate day and night final colors
	ct = texelColor1.rgb * texelBlurMask.rgb + ( texelColor2.rgb * ( 1.0 - texelBlurMask.rgb ) );
	ct = ( ct * IT ) + ( S * noise );
	
	// output final color and alpha
	gl_FragColor = vec4( ct , clamp( I * pow( RL, 1.5 ), 0.0, 1.0 ) * 0.25 );		
}
