varying vec3 L,		// light position
			 N,		// normal vector
			 C;		// camera position

uniform sampler2D texDiffuse0,
				  texNoise;

void main()
{
	vec3  R,			// reflected value
		  ct,			// total color day
		  IT,			// intensity total
		  atmos;			
	
	vec4 texelColor,		// texel from earth day texture
		 texelNoise;	// texel from noise texture
		 
	float I,			// light intensity
	      RL,			// rim lighting
	      S,			// specualar lighting
	      noise;		// noise for specular modulation
		      
	// get all texture texels
	texelColor = texture2D( texDiffuse0, gl_TexCoord[0].st );	
	texelNoise = texture2D( texNoise, gl_TexCoord[0].st );	
	
	// calculate intensity value
	I = max( dot( L, N ), 0.0 );
	
	// calculate rim light value
	RL = pow( 1.25 - max( dot( C, N ) , 0.0 ), 7.0 );
	atmos = pow( 1.25 - max( dot( C, N ) , 0.0 ), 3.0 ) * vec3( 0.35, 0.35, 0.5 );	
	
	// calculate noise value
	noise = clamp( ( texelNoise.r * 0.25 + texelColor.r * 0.5 ), 0.0, 1.0 );
	
	// calculate reflection value
	R = reflect( -L, N ) * ( 1.0 - clamp( RL, 0.0, 1.0 ) );
	
	// calcualte specular value
	S = pow( max( dot( R, C ), 0.0 ), clamp( gl_FrontMaterial.shininess, 0.1, 100.0 ) ) * 0.75;
	
	// calculate total intensity
	IT = ( ( I + ( I * RL ) ) * gl_FrontMaterial.diffuse.rgb ) + gl_FrontMaterial.ambient.rgb;
	
	// calculate day and night final colors
	ct = ( ( texelColor.rgb - atmos.g + atmos * 1.45 ) * IT ) + ( S * noise );
	
	// output final color and alpha
	gl_FragColor = vec4( ct , clamp( I * pow( RL, 1.5 ), 0.0, 1.0 ) );		
}
