varying vec3 L,		// light position
			 N,		// normal vector
			 C;		// camera position

uniform sampler2D texDiffuse,
				  texNoise;

uniform float offset;

void main()
{
	vec3  R,			// reflected value
		  ctD,			// total color day
		  IT;			// intensity total
	
	vec4 texelDay,		// texel from earth day texture
		 texelNoise;	// texel from noise texture
		 
	float I,			// light intensity
	      RL,			// rim lighting
	      S,			// specualar lighting
	      noise;		// noise for specular modulation
	   
	float localOffset = mod( offset, 1.0 );
		      
	// get all texture texels
	texelDay = texture2D( texDiffuse, gl_TexCoord[0].st );	
	texelNoise = texture2D( texNoise, gl_TexCoord[0].st );	
	
	// calculate intensity value
	I = max( dot( L,  N ), 0.0 );
	
	// calculate rim light value
	RL = pow( 1.35 - max( dot( C, N ) , 0.0 ), 3.0 ) * 0.75;	
	
	// calculate noise value
	noise = clamp( (texelNoise.r * 0.5 + clamp( ( texelDay.r - 0.5 ) * 1.75, 0.0, 1.0 ) ), 0.0, 1.0);
	
	// calculate reflection value
	R = reflect( -L,  N ) * ( 1.0 - clamp( RL, 0.0, 1.0 ) );
	
	// calcualte specular value
	S = pow( max( dot( R, C ), 0.0 ), clamp( gl_FrontMaterial.shininess - 0.5, 0.1, 100.0 ) ) * 0.35;
	
	// calculate total intensity
	IT = ( ( I + ( I * RL ) ) * gl_FrontMaterial.diffuse.rgb ) + gl_FrontMaterial.ambient.rgb;
	
	// calculate day and night final colors
	ctD = ( texelDay.rgb * IT ) + ( S * noise );
	
	// output final color and alpha
	gl_FragColor = vec4( ctD , clamp( I * pow( RL, 1.5 ), 0.0, 1.0 ) );		
}
