varying vec3 L,		// light position
			 N,		// normal vector
			 C;		// camera position

uniform sampler2D texDiffuse0,
				  texDiffuse1,
				  texSpec,
				  texNoise;

void main()
{
	vec3  R,			// reflected value
		  ctD,			// total color day
		  IT;			// intensity total
	
	vec4 texelColor,		// texel from earth day texture
		 texelGlow,
		 texelSpec,
		 texelNoise;	// texel from noise texture
		 
	float I,			// light intensity
	      RL,			// rim lighting
	      S,			// specualar lighting
	      noise;		// noise for specular modulation
		      
	// get all texture texels
	texelColor = texture2D( texDiffuse0, gl_TexCoord[0].st );	
	texelGlow = texture2D( texDiffuse1, gl_TexCoord[0].st );	
	texelSpec = texture2D( texSpec, gl_TexCoord[0].st );	
	texelNoise = texture2D( texNoise, gl_TexCoord[0].st );	
	
	// calculate intensity value
	I = max( dot( L,  N ), 0.0 );
	
	// calculate rim light value
	RL = pow( 1.35 - max( dot( C, N ) , 0.0 ), 3.0 ) * 0.75;	
	
	// calculate reflection value
	R = reflect( -L,  N ) * ( 1.0 - clamp( RL, 0.0, 1.0 ) );
	
	// calcualte specular value
	S = pow( max( dot( R, C ), 0.0 ), clamp( gl_FrontMaterial.shininess - 0.5, 0.1, 100.0 ) ) * texelSpec.r;
	
	// calculate total intensity
	IT = ( ( I + ( I * RL ) ) * gl_FrontMaterial.diffuse.rgb ) + gl_FrontMaterial.ambient.rgb + texelGlow.r;
	
	// calculate day and night final colors
	ctD = ( texelColor.rgb * IT ) + ( S * noise );
	
	// output final color and alpha
	gl_FragColor = vec4( ctD , texelGlow.r * 10.0 + clamp( I * pow( RL, 1.5 ) * 0.25 + texelGlow.r * 20.0, 0.0, 1.0 ) );		
}
