varying vec3 L,		// light position
			 N,		// normal vector
			 C;		// camera position

uniform sampler2D texDiffuse0,
				  texDiffuse1,
				  texSpec,
				  texNoise;

uniform float offset;

void main()
{
	vec3  R,			// reflected value
		  ct,			// total color
		  IT;			// intensity total			
	
	vec4 texelColor,
		 texelSpec,
		 texelNoise;	// texel from noise texture
		 
	float I,			// light intensity
	      RL,			// rim lighting
	      S,			// specualar lighting
	      noise;		// noise for specular modulation
	      
	float localOffset = mod( offset, 2.0 );
	      
	// get all texture texels
	texelColor = texture2D( texDiffuse0, gl_TexCoord[0].st );	
	texelSpec = texture2D( texSpec, gl_TexCoord[0].st );
	texelNoise = texture2D( texNoise, gl_TexCoord[0].st );	
	
	// calculate intensity value
	I = max( dot( L, N ), 0.0 );
	
	// calculate rim light value
	RL = pow( 1.35 - max( dot( C, N ) ,0.0 ), 7.0 );
	
	// calculate noise value
	noise = clamp( ( texelNoise.r + 0.25 ) * texelSpec.r, 0.0, 1.0 );
	
	// calculate reflection value
	R = reflect( -L, N ) * ( 1.0 - clamp( RL, 0.0, 1.0 ) );
	
	// calculate specular value
	S = pow( max( dot( R, C ), 0.0 ), clamp( gl_FrontMaterial.shininess, 1.0, 100.0 ) ) * 0.25;
	
	// calculate total intensity
	IT = ( ( I + ( I * RL ) ) * gl_FrontMaterial.diffuse.rgb ) + gl_FrontMaterial.ambient.rgb;
	
	// calculate day and night final colors
	ct = ( texelColor.rgb * IT ) + ( S * noise );
	
	// output final color and alpha
	gl_FragColor = vec4( ct , clamp( I * pow( RL, 1.5 ), 0.0, 1.0 )  );		
}
