varying vec3 L,		// light position
			 N,		// normal vector
			 C;		// camera position

uniform sampler2D texDiffuse0,
				  texDiffuse1,
				  texDiffuse2,
				  texNoise;

uniform float offset;

void main()
{
	vec3  R,			// reflected value
		  ctD,			// total color day
		  ctL,			// total color night
		  IT;			// intensity total
	
	vec4 texelDay,		// texel from earth day texture
		 texelLava,		// texel from earth night texture
		 texelClouds,
		 texelNoise;	// texel from noise texture
		 
	float I,			// light intensity
	      RL,			// rim lighting
	      S,			// specualar lighting
	      noise;		// noise for specular modulation
	   
	float localOffset = mod( offset, 1.0 );
		      
	// get all texture texels
	texelDay = texture2D( texDiffuse0, gl_TexCoord[0].st );	
	texelLava = texture2D( texDiffuse1, gl_TexCoord[0].st );
	texelClouds = texture2D( texDiffuse2, gl_TexCoord[0].st + vec2( localOffset * 2.0, 0.0) );	
	texelNoise = texture2D( texNoise, gl_TexCoord[0].st );	
	
	// calculate intensity value
	I = max( dot( L, N ), 0.0 );
	
	// calculate rim light value
	RL = pow( 1.35 - max( dot( C, N ) , 0.0 ), 10.0 ) * 0.5;
	
	// calculate noise value
	noise = clamp( ( texelNoise.r * 0.25 + texelDay.b * 2.0 ), 0.0, 1.0);
	
	// calculate reflection value
	R = reflect( -L, N ) * ( 1.0 - clamp( RL, 0.0, 1.0 ) );
	
	// calcualte specular value
	S = pow( max( dot( R, C ), 0.0 ), clamp( gl_FrontMaterial.shininess, 0.1, 100.0 ) ) * ( 1.0 - texelLava.r );
	
	// calculate total intensity
	IT = ( ( I + ( I * RL ) ) * gl_FrontMaterial.diffuse.rgb ) + gl_FrontMaterial.ambient.rgb;
	
	// calculate day and night final colors
	ctD = ( ( texelDay.rgb + ( texelLava.rgb * 0.5 * texelClouds.rgb ) )  * IT ) + ( S * noise );
	ctL = max( ( texelLava.rgb * ( 1.0 - I / 0.35 ) * 2.0 ), 0.0 ) * clamp( ( texelClouds.rgb - 0.25 ) * 2.0, 0.0, 1.0 );
	
	// output final color and alpha
	gl_FragColor = vec4( ctD + ctL, clamp( ( pow( 1.0 - I, 3.0 ) * texelLava.r * 2.0 ) + I * RL * 2.0, 0.0, 1.0 ) );		
}
